import { Event } from 'nostr-tools';
/**
 * Formats a public key into its npub format according to NIP-02
 * @param pubkey - The public key to format, can be in hex or npub format
 * @returns The public key in npub format
 * @throws {Error} If the public key format is invalid
 */
export declare function formatPublicKey(pubkey: string): string;
/**
 * Validates a public key format according to NIP-02
 * @param pubkey - The public key to validate, can be in hex or npub format
 * @returns True if the public key format is valid, false otherwise
 */
export declare function validatePublicKey(pubkey: string): boolean;
/**
 * Interface representing a contact in a contact list
 */
export interface Contact {
    /** The contact's public key */
    pubkey: string;
    /** The relay URL associated with this contact */
    relay: string;
    /** Optional petname (nickname) for the contact */
    petname?: string;
}
/**
 * Create a contact list event (NIP-02)
 * @param contacts - List of contacts to include
 * @param privateKey - Private key to sign the event
 * @returns Signed contact list event
 * @throws {NostrError} If event creation fails
 */
export declare const createContactList: (contacts: Contact[], privateKey: string) => Event;
/**
 * Parse a contact list event
 * @param event - Contact list event to parse
 * @returns List of contacts
 * @throws {NostrError} If parsing fails or event kind is invalid
 */
export declare const parseContactList: (event: Event) => Contact[];
